<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ca">
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="42"/>
        <source>License</source>
        <translation>Llicència</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="43"/>
        <location filename="../about.cpp" line="53"/>
        <source>Changelog</source>
        <translation>Registre de canvis</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="44"/>
        <source>Cancel</source>
        <translation>Cancel·la</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="64"/>
        <source>&amp;Close</source>
        <translation>Tan&amp;ca </translation>
    </message>
    <message>
        <location filename="../main.cpp" line="55"/>
        <source>GUI for applying assorted useful tweaks</source>
        <translation>IGU per aplicar diversos ajustos útils</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="58"/>
        <source>launches brightness-systray</source>
        <translation>engega brillantor-safata del sistema</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="59"/>
        <source>opens with display tab open.  Only valid with Xfce desktop running</source>
        <translation>obre amb la pestanya de visualització oberta. Vàlid només amb l&apos;escriptori Xfce</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="60"/>
        <source>Opens theme tab directly.  Valid on Xfce &amp; Fluxbox desktops</source>
        <translation>Obre directament amb la pestanya de tema. Vàlid amb els escriptoris Xfce i Fluxbox </translation>
    </message>
    <message>
        <location filename="../main.cpp" line="61"/>
        <source>Display additional debug output in console</source>
        <translation>Mostra la sortida addicional de depuració a la consola</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="62"/>
        <source>Opens Other tab directly.  Valid on all desktops</source>
        <translation>Obre una altra pestanya directament. Vàlid en tots els escriptoris.</translation>
    </message>
</context>
<context>
    <name>Tweak</name>
    <message>
        <location filename="../tweak.ui" line="14"/>
        <location filename="../tweak.cpp" line="71"/>
        <location filename="../tweak.cpp" line="242"/>
        <location filename="../tweak.cpp" line="261"/>
        <source>MX Tweak</source>
        <translation>MX Tweak</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="33"/>
        <source>Xfce Panel</source>
        <translation>Plafó de l&apos;Xfce</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="39"/>
        <location filename="../tweak.ui" line="233"/>
        <location filename="../tweak.ui" line="508"/>
        <location filename="../tweak.ui" line="587"/>
        <location filename="../tweak.ui" line="643"/>
        <location filename="../tweak.ui" line="670"/>
        <location filename="../tweak.ui" line="862"/>
        <location filename="../tweak.ui" line="1253"/>
        <location filename="../tweak.ui" line="1382"/>
        <location filename="../tweak.ui" line="1429"/>
        <location filename="../tweak.ui" line="1679"/>
        <source>Apply</source>
        <extracomment>apply changes</extracomment>
        <translation>Aplica</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="58"/>
        <source>Tasklist</source>
        <translation>Llista de tasques</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="64"/>
        <source>Set Tasklist plugin to:</source>
        <translation>Defineix el connector de la llista de tasques a:</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="71"/>
        <source>Docklike is the modern dock plugin for the panel. Window Buttons is the classic tasklist without dock features.</source>
        <translation>El Docklike és el connector modern d&apos;acoblament per al plafó. Window Buttons és la llista de tasques clàssica sense funcions d&apos;acoblament.</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="78"/>
        <source>Tasklist Options</source>
        <translation>Opcions de la llista de tasques</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="85"/>
        <source>Docklike Options</source>
        <translation>Opcions de l&apos;acoblador</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="95"/>
        <source>Affects 1st Panel</source>
        <translation>Afecta el 1r plafó</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="101"/>
        <location filename="../tweak.ui" line="1036"/>
        <location filename="../tweak.ui" line="1146"/>
        <location filename="../tweak.ui" line="1273"/>
        <source>Placement</source>
        <translation>Posició</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="114"/>
        <source>Backup/Restore Configuration (all panels)</source>
        <translation>Configuració de còpia de seguretat / restauració (tots els plafons)</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="127"/>
        <source>Backup current panel configuration</source>
        <translation>Còpia de seguretat de la configuració del plafó</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="141"/>
        <source>Restore selected panel configuration</source>
        <translation>Restaura la configuració del plafó seleccionat</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="148"/>
        <source>Restore default panel</source>
        <translation>Restaura el plafó per omissió</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="158"/>
        <source>Panel Plugin Scales</source>
        <translation>Escales del connector del plafó</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="164"/>
        <source>Volume</source>
        <extracomment>volume plugin scale factor</extracomment>
        <translation>Volum</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="184"/>
        <source>Power Manager</source>
        <extracomment>power manager plugin scale factor</extracomment>
        <translation>Gestor d&apos;Energia</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="221"/>
        <source>Theme</source>
        <translation>Tema </translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="227"/>
        <source>Theme Options</source>
        <translation>Opcions de Tema</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="262"/>
        <source>Remove User Theme Set</source>
        <translation>Elimina el conjunt de Tema d&apos;Usuari</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="275"/>
        <source>Themes</source>
        <translation>Temes</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="281"/>
        <source>Application</source>
        <extracomment>theme an application will get</extracomment>
        <translation>Aplicació</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="295"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Toggle Dark Mode for GTK4 libadwaita applications&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Canvia a mode fosc per aplicacions adwaita GTK4 &lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="298"/>
        <source>Dark Mode</source>
        <translation>Mode fosc</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="305"/>
        <location filename="../tweak.ui" line="1742"/>
        <source>Window Manager</source>
        <extracomment>theme a window manager border will get</extracomment>
        <translation>Gestor de Finestres</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="319"/>
        <source>Legacy Styles</source>
        <translation>Estils clàssics</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="332"/>
        <source>Icons</source>
        <extracomment>icon theme</extracomment>
        <translation>Icones</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="339"/>
        <source>Cursors</source>
        <extracomment>cursor theme</extracomment>
        <translation>Cursors</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="346"/>
        <source>Save Current Settings as a Theme Set</source>
        <extracomment>save theme settings as a group</extracomment>
        <translation>Desa els paràmetres actuals com a Conjunt de Tema</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="356"/>
        <source>Size</source>
        <extracomment>size of the cursor</extracomment>
        <translation>Mida </translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="366"/>
        <source>default</source>
        <extracomment>default cursor size determined by X server</extracomment>
        <translation>per omissió </translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="389"/>
        <location filename="../tweak.ui" line="441"/>
        <source>Compositor</source>
        <translation>Compositor</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="401"/>
        <source>Changing the VBlank mode may help alleviate some screen tearing issues. See Help for more information.</source>
        <translation>Canviar el mode VBlank pot ajudar a alleujar alguns problemes d&apos;esquinçament de pantalla. Consulteu l&apos;ajuda per obtenir més informació.</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="404"/>
        <source>VBlank</source>
        <translation>VBlank</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="412"/>
        <source>auto</source>
        <translation>automàtic</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="417"/>
        <source>glx</source>
        <translation>GLX</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="422"/>
        <source>xpresent</source>
        <translation>xpresent</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="427"/>
        <location filename="../tweak.ui" line="1010"/>
        <source>off</source>
        <extracomment>setting to 0 turns off screensaver screen blank</extracomment>
        <translation>no </translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="435"/>
        <source>Transparency and shadow options</source>
        <translation>Opcions de transparència i ombres</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="451"/>
        <source>Xfce Compositor Settings</source>
        <translation>Paràmetres del compositor de l&apos;Xfce</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="454"/>
        <source>Xfwm Settings</source>
        <translation>Paràmetres de Xfwm</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="464"/>
        <source>Launch compton-conf configuration tool</source>
        <translation>Arrenca l&apos;eina de configuració Compton-conf</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="467"/>
        <source>Picom settings</source>
        <translation>Paràmetres de Picom</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="478"/>
        <source>Edit compton.conf directly in text editor</source>
        <translation>Edita directament compton.conf a l&apos;editor de text</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="481"/>
        <source>Edit picom.conf</source>
        <translation>Edita picom.conf</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="528"/>
        <source>Display</source>
        <translation>Pantalla</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="534"/>
        <source>Display Tweaks</source>
        <translation>Ajustos de la pantalla</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="540"/>
        <source>Hardware Backlight</source>
        <extracomment>set the hardware backlight on monitors that have them</extracomment>
        <translation>Llum del fons per maquinari</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="563"/>
        <location filename="../tweak.ui" line="694"/>
        <source>TextLabel</source>
        <translation>Etiqueta</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="570"/>
        <source>GTK scaling</source>
        <extracomment>gtk scale factor</extracomment>
        <translation>Escalat GTK</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="623"/>
        <source>Choose Display for xrandr tweaks</source>
        <extracomment>choose the display that the xrandr tweaks will be acted upon</extracomment>
        <translation>Trieu Pantalla per als ajustos de xrandr </translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="633"/>
        <source>Resolution</source>
        <translation>Resolució</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="650"/>
        <source>xrandr Scaling</source>
        <extracomment>xrandr scale factor</extracomment>
        <translation>Escalat xrandr</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="677"/>
        <source>Software (xrandr) Brightness</source>
        <extracomment>adjust brightness (not backlight) via software</extracomment>
        <translation>Brillantor per programari (xrandr) </translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="701"/>
        <source>Saving is per display</source>
        <translation>L&apos;estalvi és per pantalla</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="704"/>
        <source>Save</source>
        <translation>Desa </translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="728"/>
        <source>Xfce</source>
        <translation>Xfce</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="734"/>
        <source>Desktop</source>
        <translation>Escriptori</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="740"/>
        <source>Enable single-click on desktop</source>
        <translation>Activa clic únic a l&apos;escriptori</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="747"/>
        <source>Enable Desktop Zoom </source>
        <translation>Activa el Zoom de l&apos;escriptori</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="754"/>
        <location filename="../tweak.ui" line="1343"/>
        <source>Show windows from all workspaces in panel</source>
        <translation>Mostra les finestres de tots els espais de treball al plafó</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="761"/>
        <source>Do not shorten file names on the desktop</source>
        <translation>No escurcis els noms de fitxer a l&apos;escriptori</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="771"/>
        <source>Thunar</source>
        <translation>Thunar</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="777"/>
        <source>Enable single-click in Thunar File Manager</source>
        <translation>Activa clic únic al Gestor de Fitxers Thunar</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="784"/>
        <source>Reset custom right-click actions to system defaults</source>
        <translation>Restableix les accions personalitzades del clic dret als valors predeterminats del sistema</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="791"/>
        <source>Thunar windows always open in split view</source>
        <translation>Finestres del Thunar sempre obertes en vista dividida</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="798"/>
        <source>Thunar split view opens horizontal</source>
        <translation>Vista dividida del Thunar oberta en horitzontal</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="808"/>
        <source>Show percentages in notifcations when available</source>
        <translation>Mostra el percentatge a les notificacions quan sigui possible</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="815"/>
        <source>Show GTK File Dialog action buttons at bottom of dialogs</source>
        <translation>Mostra els botons d&apos;acció del fitxer de diàleg GTK a sota dels diàlegs </translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="822"/>
        <source>(also turns off Client Side Decorations for Xfce applications)</source>
        <translation>(també desactiva les decoracions del client per a les aplicacions de l&apos;Xfce)</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="832"/>
        <source>Enable hibernate on Log Out menu </source>
        <translation>Activa &apos;hiberna&apos; al Menú de Sortida</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="839"/>
        <source>note: to hibernate, swap needs to be &gt;= RAM</source>
        <translation>Nota: per a hibernar, la memòria d&apos;intercanvi ha de ser &gt;= RAM</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="873"/>
        <source>Fluxbox</source>
        <translation>Fluxbox </translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="879"/>
        <location filename="../tweak.ui" line="1353"/>
        <source>Reset Defaults</source>
        <translation>Restableix els valors predeterminats</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="885"/>
        <source>Reset DefaultDock</source>
        <translation>Reinicia l&apos;acoblador per omissió</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="892"/>
        <source>Reset Fluxbox Menu</source>
        <translation>Reinicia el menú del Fluxbox</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="899"/>
        <source>Reset ALL mx-fluxbox settings</source>
        <translation>Reinicia TOTS els paràmetres de Fluxbox</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="906"/>
        <source>Add new default menu items, if any, to existing fluxbox menu.</source>
        <translation>Afegeix elements nous de menú predeterminats, si n&apos;hi ha, al menú existent del Fluxbox.</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="909"/>
        <source>Upgrade existing menu entries</source>
        <translation>Actualitza les entrades actuals del menú</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="919"/>
        <source>Desktop Icons</source>
        <translation>Icones de l&apos;ecriptori</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="925"/>
        <source>Toggle desktop icons</source>
        <translation>Canvia les icones de l&apos;escriptori</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="933"/>
        <location filename="../tweak.ui" line="957"/>
        <source>On</source>
        <translation>Sí</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="938"/>
        <location filename="../tweak.ui" line="962"/>
        <source>Off</source>
        <translation>No</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="946"/>
        <source>Toggle icon captions</source>
        <translation>Canvia els títols de les icones</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="967"/>
        <source>On Hover</source>
        <translation>En mantenir</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="994"/>
        <source>Screensaver</source>
        <translation>Estalvi de pantalla</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1000"/>
        <source>Idle time (minutes)</source>
        <extracomment>set the time of inactivity  before screensaver screen blank occurs</extracomment>
        <translation>temps inactiu (minuts)</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1023"/>
        <source>Toolbar Settings</source>
        <translation>Paràmetres de la barra d&apos;eines</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1029"/>
        <source>Height</source>
        <translation>Altura</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1110"/>
        <location filename="../tweak.ui" line="1220"/>
        <source>Autohide</source>
        <translation>Auto-amaga</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1117"/>
        <source>Show Toolbar</source>
        <translation>Mostra la Barra d&apos;Eines</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1124"/>
        <source>Width</source>
        <translation>Amplada</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1140"/>
        <source>Dock Settings</source>
        <translation>Paràmetres de l&apos;acoblador</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1227"/>
        <source>Manage Tint2 Panel</source>
        <translation>Gestiona el panell Tint2</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1261"/>
        <source>Plasma</source>
        <translation>Plasma</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1267"/>
        <source>Affects 1st panel</source>
        <translation>Afecta el 1r plafó</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1284"/>
        <source>Bottom</source>
        <translation>A sota </translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1289"/>
        <source>Left</source>
        <translation>Esquerra</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1294"/>
        <source>Top</source>
        <translation>A dalt</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1299"/>
        <source>Right</source>
        <translation>Dreta</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1323"/>
        <source>Workspace</source>
        <translation>Espai de treball</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1329"/>
        <source>Autostart plasma-discover system tray update notification utility</source>
        <extracomment>enable or disable autostartup of plasma-discover updater utility on login</extracomment>
        <translation>Arrenca automàticament la utilitat de notificacions d&apos;actualització a la safata del sistema</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1336"/>
        <source>Enable single-click</source>
        <translation>Activa clic-únic</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1359"/>
        <source>Reset KDE/Plasma defaults</source>
        <translation>Reinicia a KDE/Plasma per omissió</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1393"/>
        <source>Super Key</source>
        <extracomment>referring to the meta or Left Super Key</extracomment>
        <translation>Tecla Super</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1399"/>
        <source>Also known as the &quot;windows&quot; key</source>
        <translation>També coneguda com a tecla de Windows</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1402"/>
        <source>Command to run with Super (Meta) key</source>
        <extracomment>label for the field to enter the command to use with super key</extracomment>
        <translation>Ordre a executar amb la tecla Super (Meta)</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1412"/>
        <source>xfce-superkey defaults</source>
        <extracomment>indicates that xfce-superkey will select a command by its default logic</extracomment>
        <translation>Valors predeterminats de la tecla súper de l&apos;Xfce</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1419"/>
        <source>Choose application</source>
        <extracomment>description of button action to launch file dialog to choose an application</extracomment>
        <translation>Trieu l&apos;aplicació</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1450"/>
        <source>Miscellaneous</source>
        <translation>Diversos</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1456"/>
        <source>Reset Lightdm (login screen) to system default theme</source>
        <translation>Reinicia Lightdm (pantalla d&apos;entrada) al tema per omissió</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1463"/>
        <source>Enable mounting of internal drives by non-root users</source>
        <translation>Activa el muntatge de discos interns per qualsevol usuari</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1470"/>
        <source>Enable kernel sandbox</source>
        <translation>Activa l&apos;entorn de proves (sandbox)</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1477"/>
        <source>requires reboot</source>
        <translation>Cal reiniciar</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1480"/>
        <source>Enable Bluetooth adapters on boot</source>
        <translation>Activa els adaptadors Bluetooth en arrencar</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1487"/>
        <source>Enable Bluetooth battery info for connected devices (requires system restart)</source>
        <extracomment>expose battery info for connected bluetooth devices to the operating system via dbus</extracomment>
        <translation>Activa informació de bateria dels dispositius Bluetooth connectats (cal reiniciar el sistema)</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1494"/>
        <source>Early loading of KVM module is new to  kernel 6.12 and conflicts with some non-KVM virtual machine applications, including virtualbox</source>
        <extracomment>early loading is new on 6.12 kernel and conflicts with virtualbox</extracomment>
        <translation>La càrrega anticipada del mòdul KVM és una novetat del nucli 6.12 i entra en conflicte amb algunes aplicacions de màquina virtual que no són de KVM, inclosa Virtualbox.</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1497"/>
        <source>Disable early KVM module load (must be disabled for Virtualbox operation on kernel 6.12 and up)</source>
        <extracomment>disable early loading of KVM module.  necessary for virtualbox to function with kernels 6.12 and up.  actually default behavior on kernels 6.11 and earlier.</extracomment>
        <translation>Desactiva la càrrega prèvia del mòdul KVM (cal desactivar-la pel funcionament de Virtualbox amb el kernel 6.12 o superior)</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1504"/>
        <source>Apt installs additional &quot;recommends&quot; packages as dependencies</source>
        <translation>Apt instal·la els paquets addicionals &quot;recomanats&quot; com a dependències</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1511"/>
        <source>Generate fluxbox All Apps menu after package installation, removal, and updates</source>
        <translation>Genera el menú de Totes les Aplicacions de fluxbox després de la instal·lació, eliminació o actualització de paquets.  </translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1518"/>
        <source>Use Client Side Decorations (CSD) on GTK3 applications that support them (requires session restart)</source>
        <translation>Usa les Client Side Decorations (CSD) a les aplicacions GTK3 que hi siguin compatibles (cal reinici de sessió)</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1525"/>
        <source>put a hold or remove a hold on updates of Liquorix kernels</source>
        <extracomment>toggle for apt hold action on update meta packages</extracomment>
        <translation>posa o treu una retenció a les actualitzacions dels nuclis Liquorix</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1528"/>
        <source>Enable Automatic Liquorix Kernel Updates (MX ahs repository)</source>
        <extracomment>uses apt-mark to hold or unhold updates to kernel metapackages</extracomment>
        <translation>Activa les actualitzacions automàtiques del nucli Liquorix (dipòsit MX ahs)</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1535"/>
        <source>put a hold or remove a hold on updates of Debian  kernels</source>
        <extracomment>toggle for apt hold action on update meta packages</extracomment>
        <translation>posa o treu una retenció a les actualitzacions dels nuclis Debian</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1538"/>
        <source>Enable Automatic Debian Kernel Updates</source>
        <extracomment>uses apt-mark to hold or unhold updates to kernel metapackages</extracomment>
        <translation>Activa les actualitzacions automàtiques del nucli Debian </translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1545"/>
        <source>Use intel driver instead of default &quot;modesetting&quot; driver (requires restart)</source>
        <translation>Usa el controlador intel en comptes del controlador &quot;modesetting&quot; (cal reiniciar)</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1571"/>
        <source>NOTE: existing /etc/X11/xorg.conf.d/20-intel.conf will be backed up to home folder</source>
        <translation>NOTA: es farà una còpia de seguretat del fitxer /etc/X11/xorg.conf.d/20-intel.conf existent a la carpeta d&apos;inici.</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1578"/>
        <source>Use tearfree amdgpu option</source>
        <translation>Usa l&apos;opció AMDGPU sense estrips</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1585"/>
        <source>NOTE: existing /etc/X11/xorg.conf.d/20-amd.conf will be backed up to home folder</source>
        <translation>NOTA: es farà una còpia de seguretat del fitxer /etc/X11/xorg.conf.d/20-amd.conf existent a la carpeta d&apos;inici.</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1592"/>
        <source>Use tearfree radeon driver option</source>
        <translation>Usa l&apos;opció del controlador Radeon sense estrips</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1599"/>
        <source>NOTE: existing /etc/X11/xorg.conf.d/20-radeon.conf will be backed up to home folder</source>
        <translation>NOTA: es farà una còpia de seguretat del fitxer /etc/X11/xorg.conf.d/20-radeon.conf existent a la carpeta d&apos;inici.</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1606"/>
        <source>Change computer name (requires reboot)</source>
        <extracomment>option to change the system hostname, requires a reboot to be 100% effective</extracomment>
        <translation>Canvia el nom de l&apos;ordinador (cal reiniciar)</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1616"/>
        <source>Change Default Display Manager (login screen) (requires reboot)</source>
        <extracomment>option to change display manager login screen.  present if more than one display manager is installed</extracomment>
        <translation>Canvia el Gestor de Visualització (pantalla de registre) (cal reiniciar)</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1629"/>
        <source>Password for administrative tasks:</source>
        <translation>Contrasenya d&apos;administrador: </translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1636"/>
        <source>&amp;User</source>
        <translation>&amp;Usuari</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1643"/>
        <source>Root</source>
        <translation>Arrel</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1693"/>
        <source>Xfce Settings</source>
        <translation>Paràmetres de Xfce</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1699"/>
        <source>Customize the panel</source>
        <translation>Personalitzeu el plafó</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1709"/>
        <source>Panel</source>
        <translation>Plafó </translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1729"/>
        <source>Configure window behavior and shortcuts</source>
        <translation>Configureu el comportament i les dreceres de la finestra</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1762"/>
        <source>Customize the look of your desktop</source>
        <translation>Personalitzeu l&apos;aspecte de l&apos;escriptori</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1775"/>
        <source>Appearance</source>
        <translation>Aspecte </translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1787"/>
        <source>About</source>
        <translation>Quant a </translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1797"/>
        <source>Help</source>
        <translation>Ajuda </translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1855"/>
        <source>Quit application</source>
        <translation>Surt de l&apos;aplicació</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1858"/>
        <source>Close</source>
        <translation>Tanca</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1864"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../tweak.cpp" line="72"/>
        <source>--display switch only valid for Xfce</source>
        <translation>--commutador de pantalla vàlid només per Xfce</translation>
    </message>
    <message>
        <location filename="../tweak.cpp" line="241"/>
        <source>About MX Tweak</source>
        <translation>Quant a MX Tweak</translation>
    </message>
    <message>
        <location filename="../tweak.cpp" line="243"/>
        <source>Version: </source>
        <translation>Versió: </translation>
    </message>
    <message>
        <location filename="../tweak.cpp" line="244"/>
        <source>App for quick default ui theme changes and tweaks</source>
        <translation>Aplicació per al parametratge ràpid del tema IU per omissió</translation>
    </message>
    <message>
        <location filename="../tweak.cpp" line="246"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../tweak.cpp" line="247"/>
        <source>%1 License</source>
        <translation>Llicència de %1</translation>
    </message>
    <message>
        <location filename="../tweak.cpp" line="261"/>
        <source>%1 Help</source>
        <translation>Ajuda de %1</translation>
    </message>
</context>
<context>
    <name>TweakCompositor</name>
    <message>
        <location filename="../tweak_compositor.cpp" line="62"/>
        <source>None</source>
        <translation>Cap</translation>
    </message>
    <message>
        <location filename="../tweak_compositor.cpp" line="63"/>
        <source>Xfwm (Xfce) Compositor</source>
        <translation>Compositor Xfwm (Xfce)</translation>
    </message>
    <message>
        <location filename="../tweak_compositor.cpp" line="64"/>
        <source>Picom</source>
        <translation>Picom</translation>
    </message>
</context>
<context>
    <name>TweakMisc</name>
    <message>
        <location filename="../tweak_misc.cpp" line="289"/>
        <source>Please enter a computer name.</source>
        <comment>question to enter a name for the computer hostname</comment>
        <translation>Si us plau, entreu un nom per a l&apos;ordinador.</translation>
    </message>
    <message>
        <location filename="../tweak_misc.cpp" line="293"/>
        <source>Sorry, your computer name contains invalid characters.
You'll have to select a different
name before proceeding.</source>
        <comment>unacceptable characters are found in hostname, pick a new name</comment>
        <translation>Ho sento, el nom de l&apos;ordinador té caràcters no vàlids.
Cal que trieu un nom diferent
abans de continuar.</translation>
    </message>
</context>
<context>
    <name>TweakSuperKey</name>
    <message>
        <location filename="../tweak_superkey.cpp" line="43"/>
        <source>Select application to run</source>
        <comment>will show in file dialog when selection an application to run</comment>
        <translation>Trieu l&apos;aplicació a executar</translation>
    </message>
</context>
<context>
    <name>TweakTheme</name>
    <message>
        <location filename="../tweak_theme.cpp" line="64"/>
        <source>Plasma Widget Themes</source>
        <comment>theme style of the kde plasma widgets</comment>
        <translation>Temes dels ginys del Plasma</translation>
    </message>
    <message>
        <location filename="../tweak_theme.cpp" line="65"/>
        <source>Color Schemes</source>
        <comment>plasma widget color schemes</comment>
        <translation>Combinacions de color</translation>
    </message>
    <message>
        <location filename="../tweak_theme.cpp" line="66"/>
        <source>Plasma Look &amp; Feel Global Themes</source>
        <comment>plasma global themes</comment>
        <translation>Aspecte i comportament del Plasma i Temes Globals</translation>
    </message>
    <message>
        <location filename="../tweak_theme.cpp" line="139"/>
        <source>Choose a theme set</source>
        <translation>Trieu un conjunt de temes</translation>
    </message>
</context>
<context>
    <name>TweakXfcePanel</name>
    <message>
        <location filename="../tweak_xfce_panel.cpp" line="17"/>
        <source>Horizontal (Bottom)</source>
        <translation>Horitzontal (inferior)</translation>
    </message>
    <message>
        <location filename="../tweak_xfce_panel.cpp" line="18"/>
        <source>Horizontal (Top)</source>
        <translation>Horitzontal (superior)</translation>
    </message>
    <message>
        <location filename="../tweak_xfce_panel.cpp" line="20"/>
        <source>Vertical (Left)</source>
        <translation>Vertical (esquerra)</translation>
    </message>
    <message>
        <location filename="../tweak_xfce_panel.cpp" line="21"/>
        <source>Vertical (Right)</source>
        <translation>Vertical (dreta)</translation>
    </message>
    <message>
        <location filename="../tweak_xfce_panel.cpp" line="23"/>
        <source>docklike</source>
        <translation>com un acoblador</translation>
    </message>
    <message>
        <location filename="../tweak_xfce_panel.cpp" line="24"/>
        <source>Window Buttons</source>
        <translation>Botons de les finestres</translation>
    </message>
    <message>
        <location filename="../tweak_xfce_panel.cpp" line="273"/>
        <location filename="../tweak_xfce_panel.cpp" line="280"/>
        <location filename="../tweak_xfce_panel.cpp" line="297"/>
        <location filename="../tweak_xfce_panel.cpp" line="301"/>
        <source>MX Tweak</source>
        <translation>MX Tweak</translation>
    </message>
    <message>
        <location filename="../tweak_xfce_panel.cpp" line="274"/>
        <source>Plese remove special characters</source>
        <translation>Si us plau, eviteu els caràcters especials</translation>
    </message>
    <message>
        <location filename="../tweak_xfce_panel.cpp" line="274"/>
        <source>from file name</source>
        <translation>del nom del fitxer</translation>
    </message>
    <message>
        <location filename="../tweak_xfce_panel.cpp" line="280"/>
        <source>File name already exists.  Choose another name</source>
        <translation>El nom de fitxer ja hi és. Trieu-ne un altre.</translation>
    </message>
    <message>
        <location filename="../tweak_xfce_panel.cpp" line="298"/>
        <source>File is not a valid tar.xz archive file</source>
        <translation>El fitxer no és un arxiu tar.xz vàlid</translation>
    </message>
    <message>
        <location filename="../tweak_xfce_panel.cpp" line="302"/>
        <source>Archive does not contain a panel config</source>
        <translation>L&apos;arxiu no conté cap configuració de plafó</translation>
    </message>
    <message>
        <location filename="../tweak_xfce_panel.cpp" line="733"/>
        <source>Panel Preferences</source>
        <translation>Preferències del tauler</translation>
    </message>
</context>
<context>
    <name>brightness_small</name>
    <message>
        <location filename="../brightness_small.ui" line="14"/>
        <source>MainWindow</source>
        <translation>Finestra principal</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="34"/>
        <source>&gt;&gt;</source>
        <translation>&gt;&gt; </translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="41"/>
        <source>Software (xrandr) Brightness</source>
        <translation>Brillantor per programari (xrandr) </translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="61"/>
        <location filename="../brightness_small.ui" line="89"/>
        <source>TextLabel</source>
        <translation>Etiqueta</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="68"/>
        <source>Save</source>
        <translation>Desa </translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="75"/>
        <source>Hardware Backlight</source>
        <translation>Llum del fons per maquinari</translation>
    </message>
    <message>
        <location filename="../brightness_small.cpp" line="35"/>
        <source>Brightness</source>
        <translation>Brillantor</translation>
    </message>
    <message>
        <location filename="../brightness_small.cpp" line="54"/>
        <source>Display</source>
        <translation>Pantalla</translation>
    </message>
    <message>
        <location filename="../brightness_small.cpp" line="59"/>
        <source>&amp;Quit</source>
        <translation>&amp;Surt</translation>
    </message>
</context>
<context>
    <name>remove_user_theme_set</name>
    <message>
        <location filename="../remove_user_theme_set.ui" line="14"/>
        <source>Remove User Theme Set</source>
        <translation>Elimina el conjunt de Tema d&apos;Usuari</translation>
    </message>
</context>
<context>
    <name>theming_to_tweak</name>
    <message>
        <location filename="../theming_to_tweak.ui" line="14"/>
        <source>New Theme Set</source>
        <translation>Nou Conjunt de Temes</translation>
    </message>
    <message>
        <location filename="../theming_to_tweak.ui" line="20"/>
        <source>Enter name for new theme set</source>
        <translation>Entreu un nom per al nou Conjunt de Temes</translation>
    </message>
</context>
<context>
    <name>window_buttons</name>
    <message>
        <location filename="../window_buttons.ui" line="14"/>
        <location filename="../window_buttons.cpp" line="38"/>
        <source>Window Buttons</source>
        <translation>Botons de les finestres</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="23"/>
        <source>Appearance</source>
        <translation>Aspecte </translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="29"/>
        <source>Show button labels</source>
        <translation>Mostra les etiquetes dels botons</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="36"/>
        <source>Show flat buttons</source>
        <translation>Mostra botons plans</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="43"/>
        <source>Show handle</source>
        <translation>Mostra l&apos;ansa </translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="50"/>
        <source>Sorting Order:</source>
        <translation>Ordenació:</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="58"/>
        <source>Timestamp</source>
        <translation>Marca de temps</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="63"/>
        <source>Group title and timestamp</source>
        <translation>Agrupa el títol i la marca de temps</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="68"/>
        <source>Window Title</source>
        <translation>Títol de la finestra</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="73"/>
        <source>Group title and window title</source>
        <translation>Agrupa el títol i el de la finestra</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="78"/>
        <source>None, allow drag-and-drop</source>
        <translation>Cap, permet arrossegar i deixar anar</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="89"/>
        <source>Behavior</source>
        <translation>Comportament</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="95"/>
        <source>Window grouping:</source>
        <translation>Agrupament de finestres:</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="103"/>
        <source>Never</source>
        <translation>Mai</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="108"/>
        <source>Always</source>
        <translation>Sempre</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="116"/>
        <source>Middle click action:</source>
        <translation>Acció del clic del mig:</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="124"/>
        <source>Nothing</source>
        <translation>Res</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="129"/>
        <source>Close window</source>
        <translation>Tanca la finestra</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="134"/>
        <source>Minimize window</source>
        <translation>Minimitza la finestra</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="142"/>
        <source>Restore minimized windows to current workspace</source>
        <translation>Restaura les finestres minimitzades a l&apos;espai de treball actual</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="149"/>
        <source>Draw window frame when hovering over a button</source>
        <translation>Dibuixa el marc de la finestra en passar per sobre d&apos;un botó</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="156"/>
        <source>Switch windows using the mouse wheel</source>
        <translation>Canvia de finestra amb la roda del ratolí</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="166"/>
        <source>Filtering</source>
        <translation>Filtratge</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="172"/>
        <source>Show windows from all workspaces or viewports</source>
        <translation>Mostra les finestres de tots els espais de treball</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="179"/>
        <source>Show only minimized windows</source>
        <translation>Mostra només les finestres minimitzades</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="186"/>
        <source>Show windows from all monitors</source>
        <translation>Mostra les finestres de tots els monitors</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="210"/>
        <source>Close</source>
        <translation>Tanca</translation>
    </message>
</context>
<context>
    <name>xfwm_compositor_settings</name>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="14"/>
        <source>Dialog</source>
        <translation>Diàleg</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="23"/>
        <source>Feature Settings</source>
        <translation>Configuració de funcions</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="29"/>
        <source>Display fullscreen overlay windows directly</source>
        <translation>Mostra finestres superposades de mida normal directament</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="36"/>
        <source>Synchronize drawing to vertical blank</source>
        <translation>Sincronitza el dibuix amb l&apos;esborrament vertical</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="43"/>
        <source>Show windows preview in place of icons when cycling</source>
        <translation>Mostra la vista prèvia de finestres en lloc d&apos;icones quan es fa rotació</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="50"/>
        <source>Show shadows under popup windows</source>
        <translation>Mostra ombres sota les finestres emergents</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="57"/>
        <source>Show shadows under dock windows</source>
        <translation>Mostra ombres sota les finestres de l&apos;acoblador</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="64"/>
        <source>Show shadows under regular windows</source>
        <translation>Mostra ombres sota les finestres normals</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="74"/>
        <source>Opacity Settings</source>
        <translation>Configuració de l&apos;opacitat</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="80"/>
        <source>Window decorations</source>
        <translation>Decoracions de finestra</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="103"/>
        <source>Inactive windows</source>
        <translation>Finestres inactives</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="126"/>
        <source>Windows during move</source>
        <translation>Finestres en moviment</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="149"/>
        <source>Windows during resize</source>
        <translation>Finestres mentre es redimensionen</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="172"/>
        <source>Popup Windows</source>
        <translation>Finestres Emergents</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="205"/>
        <source>Close</source>
        <translation>Tanca</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.cpp" line="25"/>
        <source>Xfwm Compositor Settings</source>
        <translation>Paràmetres del compositor Xfwm</translation>
    </message>
</context>
</TS>